from setuptools import setup, find_packages

setup(
    name="snpio",
    version="1.1.0",
    url="https://github.com/btmartin721/SNPio",
    author="Bradley T. Martin and Tyler K. Chafin",
    author_email="evobio721@gmail.com",
    description="Reads and writes VCF, PHYLIP, and STRUCTURE files and performs data filtering on the alignment.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    license="GPL3",
    keywords=[
        "genomics",
        "bioinformatics",
        "population genetics",
        "SNP",
        "VCF",
        "PHYLIP",
        "STRUCTURE",
        "missing data",
        "filtering",
        "filter",
        "MAF",
        "minor allele frequency",
        "MAC",
        "minor allele count",
        "biallelic",
        "monomorphic",
        "singleton",
    ],
    platforms=["Any"],
    packages=find_packages(),
    include_package_data=True,
    python_requires=">=3.11",
    install_requires=[
        "biopython",
        "bokeh",
        "holoviews",
        "kneed",
        "matplotlib",
        "numpy",
        "pandas",
        "panel",
        "plotly",
        "requests",
        "pysam",
        "h5py",
        "scikit-learn",
        "scipy",
        "seaborn",
        "toytree",
        "tqdm",
        "kaleido",  # Required for Plotly to save static images
    ],
    extras_require={
        "docs": ["sphinx", "sphinx-rtd-theme", "sphinx-autodoc-typehints"],
        "dev": ["memory-profiler", "psutil", "mypy"],
    },
    entry_points={"console_scripts": ["snpio=run_snpio.py:main"]},
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Operating System :: OS Independent",
        "Natural Language :: English",
    ],
    project_urls={
        "Source Code": "https://github.com/btmartin721/SNPio",
        "Bug Tracker": "https://github.com/btmartin721/SNPio/issues",
    },
)
